@@ -27,7 +27,6 @@ import re
 
 try:
     import psutil
-    psutil  # workaround for pyflakes issue #13
 except ImportError:
     psutil = None
 
@@ -50,12 +49,10 @@ class DiskSpaceCollector(diamond.collector.Collector):
         """
         config = super(DiskSpaceCollector, self).get_default_config()
         config.update({
-            # Enabled by default
-            'enabled': 'True',
             'path': 'diskspace',
             # filesystems to examine
             'filesystems': 'ext2, ext3, ext4, xfs, glusterfs, nfs, ntfs, hfs,'
-            + ' fat32, fat16',
+            + ' fat32, fat16, btrfs',
 
             # exclude_filters
             #   A list of regex patterns
@@ -71,18 +68,13 @@ class DiskSpaceCollector(diamond.collector.Collector):
             # exclude everything that includes the letter "m"
             'exclude_filters': ['^/export/home'],
 
-            # We don't use any derivative data to calculate this value
-            # Thus we can use a threaded model
-            'method': 'Threaded',
-
             # Default numeric output
             'byte_unit': ['byte']
         })
         return config
 
-    def __init__(self, config, handlers):
-        super(DiskSpaceCollector, self).__init__(config, handlers)
-
+    def process_config(self):
+        super(DiskSpaceCollector, self).process_config()
         # Precompile things
         self.exclude_filters = self.config['exclude_filters']
         if isinstance(self.exclude_filters, basestring):
@@ -107,6 +99,7 @@ class DiskSpaceCollector(diamond.collector.Collector):
             return labels
 
         for label in os.listdir(path):
+            label = label.replace('\\x2f', '/')
             device = os.path.realpath(path + '/' + label)
             labels[device] = label
 
@@ -142,7 +135,7 @@ class DiskSpaceCollector(diamond.collector.Collector):
                     continue
 
                 # Process the filters
-                if self.exclude_reg.match(mount_point):
+                if self.exclude_reg.search(mount_point):
                     self.log.debug("Ignoring %s since it is in the "
                                    + "exclude_filter list.", mount_point)
                     continue
@@ -166,7 +159,7 @@ class DiskSpaceCollector(diamond.collector.Collector):
                         continue
 
                     result[(major, minor)] = {
-                        'device': device,
+                        'device': os.path.realpath(device),
                         'mount_point': mount_point,
                         'fs_type': fs_type
                     }
@@ -181,7 +174,7 @@ class DiskSpaceCollector(diamond.collector.Collector):
             partitions = psutil.disk_partitions(False)
             for partition in partitions:
                 result[(0, len(result))] = {
-                    'device': partition.device,
+                    'device': os.path.realpath(partition.device),
                     'mount_point': partition.mountpoint,
                     'fs_type': partition.fstype
                 }
@@ -206,7 +199,11 @@ class DiskSpaceCollector(diamond.collector.Collector):
                     name = 'root'
 
             if hasattr(os, 'statvfs'):  # POSIX
-                data = os.statvfs(info['mount_point'])
+                try:
+                    data = os.statvfs(info['mount_point'])
+                except OSError, e:
+                    self.log.exception(e)
+                    continue
 
                 block_size = data.f_bsize
 
@@ -257,9 +254,10 @@ class DiskSpaceCollector(diamond.collector.Collector):
                     self.publish_gauge(metric_name, metric_value, 2)
 
             if os.name != 'nt':
-                self.publish_gauge(
-                    '%s.inodes_percentfree' % name,
-                    float(inodes_free) / float(inodes_total) * 100)
+                if float(inodes_total) > 0:
+                    self.publish_gauge(
+                        '%s.inodes_percentfree' % name,
+                        float(inodes_free) / float(inodes_total) * 100)
                 self.publish_gauge('%s.inodes_used' % name,
                                    inodes_total - inodes_free)
                 self.publish_gauge('%s.inodes_free' % name, inodes_free)
