@@ -38,7 +38,7 @@ class GridEngineCollector(diamond.collector.Collector):
 
     class StatsParser(object):
         def __init__(self, document):
-            self.dom = xml.dom.minidom.parseString(document)
+            self.dom = xml.dom.minidom.parseString(document.strip())
 
         def get_tag_text(self, node, tag_name):
             el = node.getElementsByTagName(tag_name)[0]
@@ -53,7 +53,7 @@ class GridEngineCollector(diamond.collector.Collector):
 
     class QueueStatsParser(StatsParser):
         def __init__(self, document):
-            self.dom = xml.dom.minidom.parseString(document)
+            self.dom = xml.dom.minidom.parseString(document.strip())
 
         def parse(self):
             cluster_queue_summaries = self.dom.getElementsByTagName(
@@ -84,8 +84,8 @@ class GridEngineCollector(diamond.collector.Collector):
                 temp_disabled=temp_disabled,
                 manual_intervention=manual_intervention)
 
-    def __init__(self, config, handlers):
-        super(GridEngineCollector, self).__init__(config, handlers)
+    def process_config(self):
+        super(GridEngineCollector, self).process_config()
         os.environ['SGE_ROOT'] = self.config['sge_root']
 
     def get_default_config_help(self):
@@ -101,7 +101,6 @@ class GridEngineCollector(diamond.collector.Collector):
         config = super(GridEngineCollector, self).get_default_config()
         config.update({
             'bin_path': '/opt/gridengine/bin/lx-amd64/qstat',
-            'method': 'Threaded',
             'path': 'gridengine',
             'sge_root': self._sge_root(),
         })
