@@ -5,11 +5,11 @@ This class collects data from libsensors. It should work against libsensors 2.x
 and 3.x, pending support within the PySensors Ctypes binding:
 [http://pypi.python.org/pypi/PySensors/](http://pypi.python.org/pypi/PySensors/)
 
-Requires: 'sensors' to be installed, configured, and the relevant kernel modules
-to be loaded. Requires: PySensors requires Python 2.6+
+Requires: 'sensors' to be installed, configured, and the relevant kernel
+modules to be loaded. Requires: PySensors requires Python 2.6+
 
-If you're having issues, check your version of 'sensors'. This collector written
-against: sensors version 3.1.2 with libsensors version 3.1.2
+If you're having issues, check your version of 'sensors'. This collector
+written against: sensors version 3.1.2 with libsensors version 3.1.2
 
 #### Dependencies
 
@@ -21,6 +21,7 @@ import diamond.collector
 
 try:
     import sensors
+    sensors  # workaround for pyflakes issue #13
 except ImportError:
     sensors = None
 
@@ -30,7 +31,7 @@ class LMSensorsCollector(diamond.collector.Collector):
     def get_default_config_help(self):
         config_help = super(LMSensorsCollector, self).get_default_config_help()
         config_help.update({
-            'fahrenheit': "True/False",
+            'send_zero': 'Send sensor data even when there is no value'
         })
         return config_help
 
@@ -41,7 +42,7 @@ class LMSensorsCollector(diamond.collector.Collector):
         config = super(LMSensorsCollector, self).get_default_config()
         config.update({
             'path': 'sensors',
-            'fahrenheit': 'True'
+            'send_zero': False
         })
         return config
 
@@ -54,8 +55,15 @@ class LMSensorsCollector(diamond.collector.Collector):
         try:
             for chip in sensors.iter_detected_chips():
                 for feature in chip:
-                    self.publish(".".join([str(chip),
-                                           feature.label.replace(' ', '-')]),
-                                 feature.get_value())
+                    label = feature.label.replace(' ', '-')
+                    value = None
+                    try:
+                        value = feature.get_value()
+                    except Exception:
+                        if self.config['send_zero']:
+                            value = 0
+
+                    if value is not None:
+                        self.publish(".".join([str(chip), label]), value)
         finally:
             sensors.cleanup()
