@@ -34,9 +34,7 @@ class LoadAverageCollector(diamond.collector.Collector):
         """
         config = super(LoadAverageCollector, self).get_default_config()
         config.update({
-            'enabled':  'True',
             'path':     'loadavg',
-            'method':   'Threaded',
             'simple':   'False'
         })
         return config
