@@ -95,26 +95,31 @@ class PostgresqlCollector(diamond.collector.Collector):
         # Iterate every QueryStats class
         for metric_name in set(metrics):
             if metric_name not in metrics_registry:
+                self.log.error(
+                    'metric_name %s not found in metric registry' % metric_name)
                 continue
 
             for dbase in dbs:
                 conn = self._connect(database=dbase)
-                klass = metrics_registry[metric_name]
-                stat = klass(dbase, conn,
-                             underscore=self.config['underscore'])
-                stat.fetch(self.config['pg_version'])
-                for metric, value in stat:
-                    if value is not None:
-                        self.publish(metric, value)
+                try:
+                    klass = metrics_registry[metric_name]
+                    stat = klass(dbase, conn,
+                                 underscore=self.config['underscore'])
+                    stat.fetch(self.config['pg_version'])
+                    for metric, value in stat:
+                        if value is not None:
+                            self.publish(metric, value)
 
-                # Setting multi_db to True will run this query on all known
-                # databases. This is bad for queries that hit views like
-                # pg_database, which are shared across databases.
-                #
-                # If multi_db is False, bail early after the first query
-                # iteration. Otherwise, continue to remaining databases.
-                if stat.multi_db is False:
-                    break
+                    # Setting multi_db to True will run this query on all known
+                    # databases. This is bad for queries that hit views like
+                    # pg_database, which are shared across databases.
+                    #
+                    # If multi_db is False, bail early after the first query
+                    # iteration. Otherwise, continue to remaining databases.
+                    if stat.multi_db is False:
+                        break
+                finally:
+                    conn.close()
 
     def _get_db_names(self):
         """
@@ -123,7 +128,7 @@ class PostgresqlCollector(diamond.collector.Collector):
         query = """
             SELECT datname FROM pg_database
             WHERE datallowconn AND NOT datistemplate
-            AND NOT datname='postgres' ORDER BY 1
+            AND NOT datname='postgres' AND NOT datname='rdsadmin' ORDER BY 1
         """
         conn = self._connect(self.config['dbname'])
         cursor = conn.cursor(cursor_factory=psycopg2.extras.DictCursor)
@@ -155,7 +160,11 @@ class PostgresqlCollector(diamond.collector.Collector):
         else:
             conn_args['database'] = 'postgres'
 
-        conn = psycopg2.connect(**conn_args)
+        try:
+            conn = psycopg2.connect(**conn_args)
+        except Exception, e:
+            self.log.error(e)
+            raise e
 
         # Avoid using transactions, set isolation level to autocommit
         conn.set_isolation_level(0)
@@ -182,44 +191,46 @@ class QueryStats(object):
         return datname
 
     def fetch(self, pg_version):
-        cursor = self.conn.cursor(cursor_factory=psycopg2.extras.DictCursor)
         if float(pg_version) >= 9.2 and hasattr(self, 'post_92_query'):
             q = self.post_92_query
         else:
             q = self.query
 
-        cursor.execute(q, self.parameters)
-        rows = cursor.fetchall()
-        for row in rows:
-            # If row is length 2, assume col1, col2 forms key: value
-            if len(row) == 2:
-                self.data.append({
-                    'datname': self._translate_datname(self.dbname),
-                    'metric': row[0],
-                    'value': row[1],
-                })
-
-            # If row > length 2, assume each column name maps to
-            # key => value
-            else:
-                for key, value in row.iteritems():
-                    if key in ('datname', 'schemaname', 'relname',
-                               'indexrelname',):
-                        continue
-
+        cursor = self.conn.cursor(cursor_factory=psycopg2.extras.DictCursor)
+        try:
+            cursor.execute(q, self.parameters)
+            rows = cursor.fetchall()
+            for row in rows:
+                # If row is length 2, assume col1, col2 forms key: value
+                if len(row) == 2:
                     self.data.append({
-                        'datname': self._translate_datname(row.get(
-                            'datname', self.dbname)),
-                        'schemaname': row.get('schemaname', None),
-                        'relname': row.get('relname', None),
-                        'indexrelname': row.get('indexrelname', None),
-                        'metric': key,
-                        'value': value,
+                        'datname': self._translate_datname(self.dbname),
+                        'metric': row[0],
+                        'value': row[1],
                     })
 
+                # If row > length 2, assume each column name maps to
+                # key => value
+                else:
+                    for key, value in row.iteritems():
+                        if key in ('datname', 'schemaname', 'relname',
+                                   'indexrelname', 'funcname',):
+                            continue
+
+                        self.data.append({
+                            'datname': self._translate_datname(row.get(
+                                'datname', self.dbname)),
+                            'schemaname': row.get('schemaname', None),
+                            'relname': row.get('relname', None),
+                            'indexrelname': row.get('indexrelname', None),
+                            'funcname': row.get('funcname', None),
+                            'metric': key,
+                            'value': value,
+                        })
+
         # Clean up
-        cursor.close()
-        self.conn.close()
+        finally:
+            cursor.close()
 
     def __iter__(self):
         for data_point in self.data:
@@ -249,7 +260,7 @@ class DatabaseStats(QueryStats):
         JOIN pg_stat_database
         ON pg_database.datname = pg_stat_database.datname
         WHERE pg_stat_database.datname
-        NOT IN ('template0','template1','postgres')
+        NOT IN ('template0','template1','postgres', 'rdsadmin')
     """
     query = post_92_query.replace(
         'pg_stat_database.temp_files as temp_files,',
@@ -258,6 +269,19 @@ class DatabaseStats(QueryStats):
         '')
 
 
+class UserFunctionStats(QueryStats):
+    # http://www.pateldenish.com/2010/11/postgresql-track-functions-to-tune.html
+    path = "%(datname)s.functions.%(funcname)s.%(metric)s"
+    multi_db = True
+    query = """
+        SELECT funcname,
+               calls,
+               total_time/calls as time_per_call
+        FROM pg_stat_user_functions
+        WHERE calls <> 0
+    """
+
+
 class UserTableStats(QueryStats):
     path = "%(datname)s.tables.%(schemaname)s.%(relname)s.%(metric)s"
     multi_db = True
@@ -560,6 +584,7 @@ class DatabaseXidAge(QueryStats):
 metrics_registry = {
     'DatabaseStats': DatabaseStats,
     'DatabaseConnectionCount': DatabaseConnectionCount,
+    'UserFunctionStats': UserFunctionStats,
     'UserTableStats': UserTableStats,
     'UserIndexStats': UserIndexStats,
     'UserTableIOStats': UserTableIOStats,
@@ -589,6 +614,7 @@ registry = {
         'DatabaseConnectionCount',
         'DatabaseReplicationStats',
         'DatabaseXidAge',
+        'UserFunctionStats',
         'UserTableStats',
         'UserIndexStats',
         'UserTableIOStats',
