@@ -79,7 +79,7 @@ class PuppetDBCollector(diamond.collector.Collector):
                 self.config['host'], int(self.config['port']), url)
             response = urllib2.urlopen(url)
         except Exception, e:
-            self.log.error('Couldnt connect to puppetdb: %s -> %s', url, e)
+            self.log.error('Couldn\'t connect to puppetdb: %s -> %s', url, e)
             return {}
         return json.load(response)
 
