@@ -85,7 +85,7 @@ class Metric(object):
         Parse a string and create a metric
         """
         match = re.match(r'^(?P<name>[A-Za-z0-9\.\-_]+)\s+'
-                         + '\(?P<value>[0-9\.]+)\s+'
+                         + '(?P<value>[0-9\.]+)\s+'
                          + '(?P<timestamp>[0-9\.]+)(\n?)$',
                          string)
         try:
