@@ -79,9 +79,10 @@ class Server(object):
         ########################################################################
 
         if 'handlers_path' in self.config['server']:
+            handlers_path = self.config['server']['handlers_path']
+
             # Make an list if not one
-            if isinstance(self.config['server']['handlers_path'], basestring):
-                handlers_path = self.config['server']['handlers_path']
+            if isinstance(handlers_path, basestring):
                 handlers_path = handlers_path.split(',')
                 handlers_path = map(str.strip, handlers_path)
                 self.config['server']['handlers_path'] = handlers_path
@@ -154,6 +155,11 @@ class Server(object):
                         if process.name == process_name:
                             process.terminate()
 
+                collector_classes = dict(
+                    (cls.__name__.split('.')[-1], cls)
+                    for cls in collectors.values()
+                )
+
                 for process_name in running_collectors - running_processes:
                     # To handle running multiple collectors concurrently, we
                     # split on white space and use the first word as the
@@ -163,18 +169,13 @@ class Server(object):
                     if 'Collector' not in collector_name:
                         continue
 
-                    # Find the class
-                    for cls in collectors.values():
-                        cls_name = cls.__name__.split('.')[-1]
-                        if cls_name == collector_name:
-                            break
-                    if cls_name != collector_name:
+                    if collector_name not in collector_classes:
                         self.log.error('Can not find collector %s',
                                        collector_name)
                         continue
 
                     collector = initialize_collector(
-                        cls,
+                        collector_classes[collector_name],
                         name=process_name,
                         configfile=self.configfile,
                         handlers=[self.handler_queue])
